@@ -20,12 +20,11 @@ describe 'tripleo::profile::base::neutron::ovs' do
 
   shared_examples_for 'tripleo::profile::base::neutron::ovs with default params' do
 
-    let(:pre_condition) do
-      "class { '::tripleo::profile::base::neutron': step => #{params[:step]} }"
+    before :each do
+      facts.merge!({ :step => params[:step] })
     end
 
     context 'with defaults for all parameters' do
-
       let(:params) { { :step => 5 } }
 
       it 'should do nothing' do
@@ -38,8 +37,8 @@ describe 'tripleo::profile::base::neutron::ovs' do
 
   shared_examples_for 'tripleo::profile::base::neutron::ovs with vhostuser_socketdir' do
 
-    let(:pre_condition) do
-      "class { '::tripleo::profile::base::neutron': step => #{params[:step]} }"
+    before :each do
+      facts.merge!({ :step => params[:step], :vhostuser_socket_dir => params[:vhostuser_socket_dir] })
     end
 
     context 'with vhostuser_socketdir configured' do
@@ -59,29 +58,8 @@ describe 'tripleo::profile::base::neutron::ovs' do
         :mode   => '0775',
       ) }
     end
-
-    context 'with vhostuser_socketdir and its permissions configured' do
-      let :params do
-        {
-          :step => 5,
-          :vhostuser_socket_dir   => '/var/lib/vhostuser_sockets',
-          :vhostuser_socket_group => 'hugetlbfs',
-          :vhostuser_socket_user  => 'openvswitch'
-        }
-      end
-
-      it { is_expected.to contain_class('tripleo::profile::base::neutron') }
-      it { is_expected.to contain_class('neutron::agents::ml2::ovs') }
-      it { is_expected.to contain_file('/var/lib/vhostuser_sockets').with(
-        :ensure => 'directory',
-        :owner  => 'openvswitch',
-        :group  => 'hugetlbfs',
-        :mode   => '0775',
-      ) }
-    end
   end
 
-
   on_supported_os.each do |os, facts|
     context "on #{os}" do
       let(:facts) do
@@ -93,4 +71,3 @@ describe 'tripleo::profile::base::neutron::ovs' do
     end
   end
 end
-
